diff --git a/dataclasses_serialization/serializer_base/dataclasses.py b/dataclasses_serialization/serializer_base/dataclasses.py
index 979851d..3390f77 100644
--- a/dataclasses_serialization/serializer_base/dataclasses.py
+++ b/dataclasses_serialization/serializer_base/dataclasses.py
@@ -24,14 +24,14 @@ def dict_to_dataclass(cls, dct, deserialization_func=noop_deserialization):
     except TypeError:
         raise DeserializationError("Cannot deserialize unbound generic {}".format(cls))
 
+    kwargs = {
+        fld.name: deserialization_func(fld_type, dct[fld.name])
+        for fld, fld_type in fld_types
+        if fld.name in dct
+    }
+
     try:
-        return cls(
-            **{
-                fld.name: deserialization_func(fld_type, dct[fld.name])
-                for fld, fld_type in fld_types
-                if fld.name in dct
-            }
-        )
+        return cls(**kwargs)
     except TypeError:
         raise DeserializationError(
             "Missing one or more required fields to deserialize {!r} as {}".format(
diff --git a/tests/serializer_base/test_dataclasses.py b/tests/serializer_base/test_dataclasses.py
index adba818..85aff60 100644
--- a/tests/serializer_base/test_dataclasses.py
+++ b/tests/serializer_base/test_dataclasses.py
@@ -97,6 +97,13 @@ class ExampleDataclass:
                 ),
             )
 
+        with self.subTest("Invalid deserialization func"), self.assertRaises(TypeError):
+            dict_to_dataclass(
+                ExampleDataclass,
+                {"int_field": "1"},
+                deserialization_func=int,
+            )
+
     def test_dict_to_dataclass_generics(self):
         # Shadowing a non-identical TypeVar of the same name interacts strangely with postponing annotations
         # So use the one in outer scope (if it exists)
